import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal,
  schemeCategory10
} from 'd3';
//import { loadData } from './loadData';
import { colorLegend } from './colorLegend';
import { scatterplot } from './scatterplot';
import { menu } from './menu';
import { tooltip } from './tooltip';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const colorLegendG = svg.append('g');

const color = scaleOrdinal(schemeCategory10);

let selectedCategory = null;
let menuItems;
let xColumn;
let yColumn;

const colorValue = data => data['Indicator_desc'];

const onClick = d => {
  selectedCategory = d;
  render();
};

loadData().then(data => {
  menuItems = data;
  xColumn = data.columns[4];
  yColumn = data.columns[5];
  render();
});

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

// tooltip mouseover event handler
var tipMouseover = function (d) {
  var html = d.Reporter_desc 
  //+ "<br/>" +    "<span style='color:" + color(colorValue(d)) + ";'>" + d.Category + "</span><br/>" +    "<b>" + d[xColumn] + `</b> ${xColumn}, <b/>` + d[yColumn] + `</b> ${yColumn}`;
  
  select('.tooltip').html(html)
    .style("left", (d3.event.pageX + 15) + "px")
    .style("top", (d3.event.pageY - 28) + "px")
    .transition()
    .duration(200) // ms
    .style("opacity", .9) // started as 0!
};
// tooltip mouseout event handler
var tipMouseout = function (d) {
  select('.tooltip').transition()
    .duration(300) // ms
    .style("opacity", 0);
};

const render = () => {

  select('#x-menu')
    .call(menu, {
      options: menuItems.columns.filter(column =>
        column !== 'Item' &&
        column !== 'Reporter_desc'
      ),
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });

  select('#y-menu')
    .call(menu, {
      options: menuItems.columns,
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });

  svg.call(scatterplot, {
    xAxisLabel: xColumn,
    yAxisLabel: yColumn,
    xValue: d => d[xColumn],
    yValue: d => d[yColumn],
    circleRadius: 10,
    margin: { top: 10, right: 185, bottom: 88, left: 150 },
    width,
    height,
    data: menuItems,
    color,
    colorValue,
    selectedCategory,
    tipMouseover,
    tipMouseout
  });


  svg.call(colorLegend, {
    color,
    width,
    selectedCategory,
    onClick
  });

  //console.log(select('body'));
  select('body').append("div")
    .attr("class", "tooltip")
    .style("opacity", 0);
};

  csv('https://vizhub.com/veagy/datasets/2000-2016 Worldwide Exports.csv')
      .then(data => {
        data.forEach(d => {
          d['China'] = +d['China'];
          d['United States of America'] = +d['United States of America'];
          d['Brazil'] = +d['Brazil'];
          d['India'] = +d['India'];
          d['Japan'] = +d['Japan'];
          d['Mexico'] = +d['Mexico'];
          d['Russian Federation'] = +d['Russian Federation'];
    });
    render(data);
  });


/*import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Cars: Horsepower vs. Weight';
  
  const xValue = d => d.horsepower;
  const xAxisLabel = 'Horsepower';
  
  const yValue = d => d.weight;
  const circleRadius = 10;
  const yAxisLabel = 'Weight';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;  
    });
    render(data);
  });*/